@@ -14,10 +14,10 @@
 #
 import os
 import sys
+
 sys.path.insert(0, os.path.abspath('..'))
 import sphinx_rtd_theme
 
-
 # -- Project information -----------------------------------------------------
 
 project = 'psprint'
@@ -25,8 +25,7 @@ copyright = '2021, Pradyumna Paranjape'
 author = 'Pradyumna Paranjape'
 
 # The full version, including alpha/beta/rc tags
-release = '1!1.0.2'
-
+release = '1!1.0.5'
 
 # -- General configuration ---------------------------------------------------
 
@@ -34,8 +33,12 @@ release = '1!1.0.2'
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    'sphinx.ext.todo', 'sphinx.ext.autodoc', 'sphinx.ext.napoleon',
-    'sphinx.ext.viewcode', 'sphinx_rtd_theme', "sphinx_autodoc_typehints",
+    'sphinx.ext.todo',
+    'sphinx.ext.autodoc',
+    'sphinx.ext.napoleon',
+    'sphinx.ext.viewcode',
+    'sphinx_rtd_theme',
+    "sphinx_autodoc_typehints",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -46,7 +49,6 @@ templates_path = ['_templates']
 # This pattern also affects html_static_path and html_extra_path.
 exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
 
-
 # -- Options for HTML output -------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
